(function(){
"use strict";

var module = {
    el_ext_list: document.getElementById('ext_list'),
    ext_list: [],
    loadExtensions: function(){
        return new Promise((resolve, reject)=>{
            chrome.management.getAll(exts=>{
                var i, ext_list = [];
                for (i = 0; i < exts.length; ++i) {
                    if (exts[i].type !== 'extension')
                        continue;
                    var icons = exts[i].icons || [];
                    if (icons.length == 0)
                        icons[0] = {url: chrome.runtime.getURL('../images/no-logo.png') };
                    else
                    {
                        icons.sort((a, b) => {
                            return a.size > b.size ? -1 : 1;
                        });
                    }
                    ext_list.push({
                        icon: icons[0].url,
                        id: exts[i].id,
                        type: exts[i].type,
                        name: exts[i].name,
                        version: exts[i].version,
                        enabled: exts[i].enabled ? '1' : '0',
                        checked: exts[i].enabled ? 'checked' : '',
                        install_type: exts[i].installType
                    });
                }
                this.ext_list = ext_list;
                this.ext_list.sort((a, b)=>a.name>b.name ? 1 : -1)
                resolve();
            });
        });
    },
    draw: function(){
        let html = '';
        this.ext_list.forEach(ext=>{
            html += `<tr data-install="${ext.install_type}"
                title="Intall type: ${ext.install_type}">
                <td><img class="ext__icon" src="${ext.icon}"></td>
                <td>${ext.name}
                    <span class="gray" title="version">${ext.version}<span>
                </td>
                <td class="right-align">
                    <input data-id="${ext.id}" type="checkbox" ${ext.checked}>
                </td>
            </tr>`;
        });
        this.el_ext_list.innerHTML = html;
    },
    addEvent: function(){
        this.el_ext_list.addEventListener('change', e=>{
            var el = e.target;
            if (el.tagName !== 'INPUT')
                return;
            var ext_id = el.dataset["id"];
            chrome.management.setEnabled(ext_id, !!el.checked, () => {});
        }, false);
    },
    run: function(){
        this.loadExtensions()
            .then(()=>this.draw())
            .then(()=>this.addEvent());
    }
};

module.run();

})();
